Voxelization
---------------

.. featurizer::  VoxelGrid
    :id: VoxelGrid
    :considers_geometry: True
    :considers_structure_graph: False
    :encodes_chemistry: optionally
    :scope: global
    :scalar: False

    We base our implementation on `pyntcloud <https://pyntcloud.readthedocs.io/en/latest/>`_, a Python library for dealing with point clouds.

    Similar features have been used by [Hung2022]_ and [Cho2021]_.
